Coverage report

|  |  | Statements |  | Branches |  | Total
--- | --- | --- | --- | --- | --- | --- | ---
File | function |  | coverage | statements | missing | excluded |  | coverage | branches | partial |  | coverage
src / herkules / Herkules.py | _herkules_diff_prepare |  | 71% | 14 | 4 | 0 |  | 60% | 10 | 4 |  | 67%
tests / test_beetle.py | TestBeetle.test_difference_error_handling_no_entries_1 |  | 80% | 5 | 1 | 0 |  | 100% | 0 | 0 |  | 80%
tests / test_beetle.py | TestBeetle.test_difference_error_handling_no_entries_2 |  | 80% | 5 | 1 | 0 |  | 100% | 0 | 0 |  | 80%
tests / test_beetle.py | TestBeetle.test_difference_error_handling_no_metadata_1 |  | 80% | 5 | 1 | 0 |  | 100% | 0 | 0 |  | 80%
tests / test_beetle.py | TestBeetle.test_difference_error_handling_no_metadata_2 |  | 80% | 5 | 1 | 0 |  | 100% | 0 | 0 |  | 80%
tests / test_beetle.py | TestBeetle.test_difference_create_folder_separate_run |  | 73% | 11 | 3 | 0 |  | 100% | 0 | 0 |  | 73%
Total |  |  | 98% | 487 | 11 | 38 |  | 96% | 94 | 4 |  | 97%

No items found using the specified filter.

53 functions skipped due to complete coverage.